@@ -16,12 +16,12 @@ use Win32 qw();
 use URI qw();
 
 our @EXPORT =
-  qw(test_run_dist test_add test_verify_files_short test_verify_files_medium
+  qw(test_run_dist test_verify_files_short test_verify_files_medium
   test_verify_files_long test_verify_portability test_cleanup);
 push @EXPORT, @Test::More::EXPORT;
 
-our $VERSION = '0.203';
-$VERSION = eval $VERSION; ##no critic(RequireConstantVersion)
+our $VERSION = '0.300';
+$VERSION =~ s/_//ms;
 
 my $tests_completed = 0;
 
@@ -32,7 +32,9 @@ my $tests_completed = 0;
 
 sub _make_path {
 	my $dir = rel2abs( catdir( curdir(), @_ ) );
-	File::Path::mkpath($dir) unless -d $dir;
+	if ( not -d $dir ) {
+		File::Path::mkpath($dir);
+	}
 	ok( -d $dir, 'Created ' . $dir );
 	$tests_completed++;
 	return $dir;
@@ -40,7 +42,9 @@ sub _make_path {
 
 sub _remake_path {
 	my $dir = rel2abs( catdir( curdir(), @_ ) );
-	File::Remove::remove( \1, $dir ) if -d $dir;
+	if ( -d $dir ) {
+		File::Remove::remove( \1, $dir );
+	}
 	File::Path::mkpath($dir);
 	ok( -d $dir, 'Created ' . $dir );
 	$tests_completed++;
@@ -48,22 +52,26 @@ sub _remake_path {
 }
 
 sub _paths {
-	my $class = shift;
-	my $subpath = shift || q{};
+	my $class    = shift;
+	my $subpath  = shift || q{};
+	my $testpath = shift || 't';
 
- # Create base and download directory so we can do a GetShortPathName on it.
-	my $basedir  = rel2abs( catdir( 't', "tmp$subpath" ) );
-	my $download = rel2abs( catdir( 't', 'download' ) );
+	# Create base and download directory so we can do a
+	# GetShortPathName on it.
+	my $basedir  = rel2abs( catdir( $testpath, "tmp$subpath" ) );
+	my $download = rel2abs( catdir( $testpath, 'download' ) );
 
 	if ( $basedir =~ m{\s}sm ) {
 		plan( skip_all =>
 			  'Cannot test successfully in a test directory with spaces' );
 	}
 
-	File::Path::mkpath($basedir)  unless -d $basedir;
-	File::Path::mkpath($download) unless -d $download;
-	$basedir  = Win32::GetShortPathName($basedir);
-	$download = Win32::GetShortPathName($download);
+	if ( not -d $basedir ) {
+		File::Path::mkpath($basedir);
+	}
+	if ( not -d $download ) {
+		File::Path::mkpath($download);
+	}
 	diag("Test base directory: $basedir");
 
 	# Make or remake the subpaths
@@ -112,18 +120,6 @@ sub _force {
 	}
 }
 
-##sub _cpan {
-##	if ( $ENV{PERL_TEST_PERLDIST_CPAN} ) {
-##		return URI->new( $ENV{PERL_TEST_PERLDIST_CPAN} );
-##	}
-##	my $path = rel2abs( catdir( 't', 'data', 'cpan' ) );
-##	Test::More::ok( -d $path, 'Found CPAN directory' );
-##	Test::More::ok( -d catdir( $path, 'authors', 'id' ),
-##		'Found id subdirectory' );
-##	$tests_completed += 2;
-##	return URI::file->new( $path . q{\\} );
-##}
-
 
 
 sub new_test_class_short {
@@ -131,6 +127,7 @@ sub new_test_class_short {
 	my $test_number   = shift;
 	my $test_version  = shift;
 	my $class_to_test = shift;
+	my $testpath      = shift;
 
 	if ( $OSNAME ne 'MSWin32' ) {
 		plan( skip_all => 'Not on Win32' );
@@ -141,10 +138,11 @@ sub new_test_class_short {
 	}
 
 	my $test_class =
-	  $self->create_test_class_short( $test_number, $test_version,
+	  $self->_create_test_class_short( $test_number, $test_version,
 		$class_to_test );
 	my $test_object = eval {
-		my $obj = $test_class->new( $self->_paths($test_number),
+		my $obj =
+		  $test_class->new( $self->_paths( $test_number, $testpath ),
 			$self->_cpan_release(), $self->_forceperl(), $self->_force(),
 			@_ );
 		return $obj;
@@ -175,20 +173,25 @@ sub new_test_class_medium {
 	my $test_number   = shift;
 	my $test_version  = shift;
 	my $class_to_test = shift;
+	my $testpath      = shift;
 
 	if ( $OSNAME ne 'MSWin32' ) {
 		plan( skip_all => 'Not on Win32' );
 	}
+	if ( not -d 'blib') {
+		plan( skip_all => 'Perl::Dist::WiX::Toolchain has problems if ' .  
+		'dmake or Build has not been ran before testing.' );
+	}
 	if ( rel2abs( curdir() ) =~ m{[.]}ms ) {
 		plan( skip_all =>
 			  'Cannot be tested in a directory with an extension.' );
 	}
 
 	my $test_class =
-	  $self->create_test_class_medium( $test_number, $test_version,
+	  $self->_create_test_class_medium( $test_number, $test_version,
 		$class_to_test );
 	my $test_object = eval {
-		$test_class->new( $self->_paths($test_number),
+		$test_class->new( $self->_paths( $test_number, $testpath ),
 			$self->_cpan_release(), $self->_forceperl(), $self->_force(),
 			@_ );
 	};
@@ -219,20 +222,25 @@ sub new_test_class_long {
 	my $test_number   = shift;
 	my $test_version  = shift;
 	my $class_to_test = shift;
+	my $testpath      = shift;
 
 	if ( $OSNAME ne 'MSWin32' ) {
 		plan( skip_all => 'Not on Win32' );
 	}
+	if ( not -d 'blib') {
+		plan( skip_all => 'Perl::Dist::WiX::Toolchain has problems if ' .  
+		'dmake or Build has not been ran before testing.' );
+	}
 	if ( rel2abs( curdir() ) =~ m{[.]}ms ) {
 		plan( skip_all =>
 			  'Cannot be tested in a directory with an extension.' );
 	}
 
 	my $test_class =
-	  $self->create_test_class_long( $test_number, $test_version,
+	  $self->_create_test_class_long( $test_number, $test_version,
 		$class_to_test );
 	my $test_object = eval {
-		$test_class->new( $self->_paths($test_number),
+		$test_class->new( $self->_paths( $test_number, $testpath ),
 			$self->_cpan_release(), $self->_forceperl(), $self->_force(),
 			@_ );
 	};
@@ -294,17 +302,11 @@ sub test_run_dist {
 
 
 
-sub test_add {
-	$tests_completed++;
-
-	return;
-}
-
-
-
 sub test_verify_files_short {
 	my $test_number = shift;
-	my $test_dir = catdir( 't', "tmp$test_number", qw{ image c bin } );
+	my $testpath = shift || 't';
+	my $test_dir =
+	  catdir( $testpath, "tmp$test_number", qw{ image c bin } );
 
 	ok( -f catfile( $test_dir, qw{ dmake.exe } ), 'Found dmake.exe' );
 
@@ -321,9 +323,10 @@ sub test_verify_files_short {
 sub test_verify_files_medium {
 	my $test_number = shift;
 	my $dll_version = shift;
+	my $testpath    = shift || 't';
 
 	my $dll_file = "perl${dll_version}.dll";
-	my $test_dir = catdir( 't', "tmp$test_number", 'image' );
+	my $test_dir = catdir( $testpath, "tmp$test_number", 'image' );
 
 	# C toolchain files
 	ok( -f catfile( $test_dir, qw{ c bin dmake.exe } ), 'Found dmake.exe',
@@ -374,7 +377,7 @@ sub test_verify_files_medium {
 
 
 
-sub create_test_class_short {
+sub _create_test_class_short {
 	my $self         = shift;
 	my $test_number  = shift;
 	my $test_version = shift;
@@ -411,11 +414,11 @@ EOF
 
 	eval $code;
 	return $answer;
-} ## end sub create_test_class_short
+} ## end sub _create_test_class_short
 
 
 
-sub create_test_class_medium {
+sub _create_test_class_medium {
 	my $self         = shift;
 	my $test_number  = shift;
 	my $test_version = shift;
@@ -473,11 +476,11 @@ sub create_test_class_medium {
 EOF
 
 	return $answer;
-} ## end sub create_test_class_medium
+} ## end sub _create_test_class_medium
 
 
 
-sub create_test_class_long {
+sub _create_test_class_long {
 	my $self         = shift;
 	my $test_number  = shift;
 	my $test_version = shift;
@@ -527,16 +530,17 @@ sub create_test_class_long {
 EOF
 
 	return $answer;
-} ## end sub create_test_class_long
+} ## end sub _create_test_class_long
 
 
 
 sub test_verify_files_long {
 	my $test_number = shift;
 	my $dll_version = shift;
+	my $testpath    = shift || 't';
 
 	my $dll_file = "perl${dll_version}.dll";
-	my $test_dir = catdir( 't', "tmp$test_number", 'image' );
+	my $test_dir = catdir( $testpath, "tmp$test_number", 'image' );
 
 	# C toolchain files
 	ok( -f catfile( $test_dir, qw{ c bin dmake.exe } ), 'Found dmake.exe',
@@ -591,6 +595,7 @@ sub test_verify_files_long {
 sub test_verify_portability {
 	my $test_number   = shift;
 	my $base_filename = shift;
+	my $testpath      = shift || 't';
 
 	my $test_dir = catdir( 't', "tmp$test_number" );
 
@@ -616,11 +621,12 @@ sub test_verify_portability {
 
 sub test_cleanup {
 	my $test_number = shift;
+	my $testpath = shift || 't';
 
 	if ( Test::Builder->new()->is_passing() ) {
 
 		diag('Removing build files on successful test.');
-		my $dir = catdir( 't', "tmp$test_number" );
+		my $dir = catdir( $testpath, "tmp$test_number" );
 		File::Remove::remove( \1, $dir );
 	} else {
 		diag('Did not pass, so not removing files.');
@@ -645,7 +651,7 @@ __END__
 
 =begin readme text
 
-Test::Perl::Dist version 0.203
+Test::Perl::Dist version 0.300
 
 =end readme
 
@@ -657,7 +663,7 @@ Test::Perl::Dist - Test module for Perl::Dist::WiX and subclasses.
 
 =head1 VERSION
 
-This document describes Test::Perl::Dist version 0.203
+This document describes Test::Perl::Dist version 0.300
 
 =begin readme
 
@@ -695,20 +701,21 @@ Alternatively, to install with Module::Build, you can use the following commands
 		$^W = 1;
 	}
 
-	use Test::Perl::Dist;
+	use Test::Perl::Dist 0.300;
+	use File::Spec::Functions qw(catdir);
 
 	#####################################################################
 	# Complete Generation Run
 
 	# Create the dist object
 	my $dist = Test::Perl::Dist->new_test_class_medium(
-		901, '589', 'Perl::Dist::Strawberry', 
+		901, '589', 'Perl::Dist::Strawberry', catdir(qw(xt release))
 		msi => 0
 	);
 
 	test_run_dist( $dist );
 
-	test_verify_files_medium(901, '58');
+	test_verify_files_medium(901, '58', catdir(qw(xt release));
 
 	done_testing();
 
@@ -727,11 +734,13 @@ L<Test::More|Test::More>, in addition to the routines documented here.
 The only difference is in L<done_testing|/done_testing>, as documented below.
 
 =head2 new_test_class_short
+
 =head2 new_test_class_medium
+
 =head2 new_test_class_long
 
 	my $dist = Test::Perl::Dist->new_test_class_medium(
-		901, '589', 'Perl::Dist::Strawberry', 
+		901, '589', 'Perl::Dist::Strawberry', catdir(qw(xt release)),
 		msi => 0
 	);
 
@@ -739,8 +748,8 @@ Returns a distribution class to run and test against that is a subclass
 of the class being tested.
 
 The first parameter is the test number, the second refers to the version of 
-perl to build (589 for perl 5.8.9, for instance) and the third is the class 
-being tested.
+perl to build (589 for perl 5.8.9, for instance), the third is the class 
+being tested, and the fourth is the directory the test is in.
 
 Any parameters after that are passed to the constructor of the distribution 
 class, which passes them on to the class being tested.
@@ -764,33 +773,39 @@ If the class being tested returns an exception when ran, that
 exception is printed, and all testing is stopped.
 
 =head2 test_verify_files_short
+
 =head2 test_verify_files_medium
+
 =head2 test_verify_files_long
 
-	test_verify_files_medium(901, '58');
+	test_verify_files_medium(901, '58', catdir(qw(xt release)));
 
 This checks that certain files were created.
 
 The first parameter is the test number, the second parameter refers to the 
 first two parts of the perl version ('58' for 5.8.9, '510' for 5.10.0 or 
-5.10.1).
+5.10.1), and the third parameter is the directory the test is in.
 
 =head2 test_verify_portability
 
-	test_verify_portability(901, $dist->output_base_filename());
+	test_verify_portability(901, $dist->output_base_filename(), catdir(qw(xt release)));
 
 This checks that certain files were created that are required for a 
 portable distribution.
 
 The first parameter is the test number, the second parameter is the base 
-filename of the dist being tested, as returned from output_base_filename.
+filename of the dist being tested, as returned from output_base_filename, 
+and the third parameter is the directory the test is in.
 
-=head2 done_testing
+=head2 test_cleanup
 
-	test_cleanup(901);
+	test_cleanup(901, catdir(xt release));
 	
 This cleans up the build files if all tests have been successful.
 
+The first parameter is the test number, and the second parameter is the 
+directory the test is in.
+
 =head2 done_testing
 
 	done_testing();
@@ -817,12 +832,12 @@ $ENV{PERL_RELEASE_TEST_PERLDIST_CPAN} is used to point at a preferred
 (or local - it can be a file:// URL) mirror for CPAN.
 
 If $ENV{PERL_RELEASE_TEST_FORCEPERL} is defined, it passes 
-forceperl => 1 to the classes being tested, which skips testing perl
-after compilation.
+C<forceperl => 1> to the classes being tested, which skips testing perl
+after compilation. This can speed up testing.
 
 If $ENV{PERL_RELEASE_TEST_FORCE} is defined, it passes 
-force => 1 to the classes being tested, which skips testing both
-perl and the additional modules installed.
+C<force => 1> to the classes being tested, which skips testing both
+perl and the additional modules installed. This can speed up testing.
 
 =for readme continue
 
@@ -837,7 +852,8 @@ L<Win32|Win32> version 0.39.
 
 =head1 INCOMPATIBILITIES
 
-None reported.
+0.300 has an incompatible API change to precious versions in order to support 
+the tests not being in 't'.
 
 =head1 BUGS AND LIMITATIONS
 
